position property
LatLng
position
getter/setter pair
This is a LatLng object that represents the position of the marker on the map.
Implementation
coord.LatLng position;
This is a LatLng object that represents the position of the marker on the map.
coord.LatLng position;