CanvasMarkerLayer class

A layer that displays a list of CanvasMarkers on a FlutterMap using

Inheritance

Constructors

CanvasMarkerLayer({Key? key, required List<CanvasMarker> markers, bool showDebugRect = false, bool showDebugHitArea = false, bool drawHitMarkerLast = false, bool cullMarkers = true})
const

Properties

cullMarkers bool
Whether to cull markers that are outside the visible area.
final
drawHitMarkerLast bool
If you perform hit testing, this determines whether the hit marker is drawn last. Ensures the hit marker is always on top of other markers.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
markers List<CanvasMarker>
The list of markers to display on the map.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDebugHitArea bool
/ Whether to show debug hit areas for markers.
final
showDebugRect bool
Whether to show debug marker bounds rectangles.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited